# OpenDSSDirect.py [![Build Status](https://travis-ci.org/NREL/OpenDSSDirect.py.svg?branch=master)](https://travis-ci.org/NREL/OpenDSSDirect.py) [![Build Status](https://ci.appveyor.com/api/projects/status/github/NREL/OpenDSSDirect.py?branch=master&svg=true)](https://ci.appveyor.com/project/kdheepak/opendssdirect-py) [![PyPI](https://img.shields.io/pypi/v/OpenDSSDirect.py.svg)](https://pypi.python.org/pypi/OpenDSSDirect.py/)

OpenDSSDirect.py is a Python package implements a "direct" library interface to [OpenDSS](http://smartgrid.epri.com/SimulationTool.aspx).
OpenDSS is an open-source distribution system simulator. See [OpenDSSDirect.jl](https://github.com/tshort/OpenDSSDirect.jl) for a similar package in Julia.

**This package is available for Windows, Mac and Linux.**

### Documentation

The documentation for this package can be found [here](http://nrel.github.io/OpenDSSDirect.py).

### Installation

**Recommended**: Install Python using Miniconda or Anaconda

Open a command line interface and type the following.

```bash
pip install OpenDSSDirect.py
```

See [installation] instructions for more information.

### Thanks

Thanks to @tshort, Davis, @temcdrm, @GordStephen and @Muxelmann for their input and comments.

See @Muxelmann's repo [here](https://github.com/Muxelmann/OpenDSSDirect.make) on how to build OpenDSS for Linux.

